@@ -1,4 +1,4 @@
-//$Id: add-resource.cc,v 1.7 2001/08/28 15:00:21 cactus Exp $ -*- c++ -*-
+//$Id: add-resource.cc,v 1.8 2001/10/19 20:17:55 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -41,16 +41,16 @@ GUI::AddResourceWin::AddResourceWin ()
 
     menu = optmenu->get_menu ();
     menu->items ().clear ();
-    menu->items ().push_back (Gtk::Menu_Helpers::MenuElem
-			      (_("Dialog"),
-			       SigC::bind (
-				   SigC::slot (this, &AddResourceWin::resource_type_cb),
-				   Resources::RESOURCE_DIALOG)));
     menu->items ().push_back (Gtk::Menu_Helpers::MenuElem
 			      (_("Form"),
 			       SigC::bind (
 				   SigC::slot (this, &AddResourceWin::resource_type_cb),
 				   Resources::RESOURCE_FORM)));
+    menu->items ().push_back (Gtk::Menu_Helpers::MenuElem
+			      (_("Dialog"),
+			       SigC::bind (
+				   SigC::slot (this, &AddResourceWin::resource_type_cb),
+				   Resources::RESOURCE_DIALOG)));
     menu->items ().push_back (Gtk::Menu_Helpers::MenuElem
 			      (_("Menu"),
 			       SigC::bind (
@@ -61,9 +61,14 @@ GUI::AddResourceWin::AddResourceWin ()
 			       SigC::bind (
 				   SigC::slot (this, &AddResourceWin::resource_type_cb),
 				   Resources::RESOURCE_STRING)));
+    menu->items ().push_back (Gtk::Menu_Helpers::MenuElem
+			      (_("Free-text blob"),
+			       SigC::bind (
+				   SigC::slot (this, &AddResourceWin::resource_type_cb),
+				   Resources::RESOURCE_BLOB)));
 
     optmenu->set_history (0);
-    res_type = Resources::RESOURCE_DIALOG;
+    res_type = Resources::RESOURCE_FORM;
 
     dialog->editable_enters (*entry);
     dialog->close_hides (true);
@@ -85,8 +90,7 @@ void GUI::AddResourceWin::run ()
     if (dialog_result != -1)
     {
 	if (dialog_result == 0)
-	    if (entry->get_text () != "")
-		ResourceManager::create_resource (res_type, entry->get_text ());
+	    ResourceManager::create_resource (res_type, entry->get_text ());
     }
 }
 
