@@ -1,4 +1,4 @@
-//$Id: app-res.h,v 1.4 2001/08/18 14:23:01 cactus Exp $ -*- c++ -*-
+//$Id: app-res.h,v 1.6 2001/09/16 13:06:06 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -16,8 +16,8 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
 
-#ifndef GUIKATCHU_APP_RES_H
-#define GUIKATCHU_APP_RES_H
+#ifndef GUIKACHU_APP_RES_H
+#define GUIKACHU_APP_RES_H
 
 namespace Guikachu
 {
@@ -57,8 +57,8 @@ namespace Guikachu
 	    void reset ();
 	    
 	private:
-	    bool load (xmlDocPtr xml_doc, xmlNodePtr node);
-	    void save (xmlNodePtr node) const;
+	    bool load (StorageNode &node);
+	    void save (StorageNode &node) const;
 	    void save_rcp (ostream &ostr) const;
 	    friend ostream& operator<< (ostream &ostr, const Application *res);
 
@@ -69,4 +69,4 @@ namespace Guikachu
     };
 };
 
-#endif /* !GUIKATCHU_APP_RES_H */
+#endif /* !GUIKACHU_APP_RES_H */
