@@ -1,4 +1,4 @@
-//$Id: dialog-res.cc,v 1.13 2001/09/16 13:06:06 cactus Exp $ -*- c++ -*-
+//$Id: dialog-res.cc,v 1.14 2001/10/09 16:37:12 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -146,7 +146,7 @@ void Resources::Dialog::save (StorageNode &node) const
     }
 
     /* Buttons */
-    vector<string> button_vec = buttons;
+    const vector<string> &button_vec = buttons;
     if (button_vec.size ())
     {
 	my_node = node.add_node ("buttons");
@@ -194,7 +194,7 @@ void Resources::Dialog::save_rcp (ostream &ostr) const
     {
 	ostr << "  BUTTONS ";
 
-	vector<string> buttons_vec = buttons ();
+	const vector<string> &buttons_vec = buttons;
 	for (vector <string>::const_iterator i = buttons_vec.begin ();
 	     i !=  buttons_vec.end (); i++)
 	    ostr << "\"" << *i << "\" ";
