@@ -1,4 +1,4 @@
-//$Id: button-canvas.h,v 1.2 2001/05/14 16:54:11 cactus Exp $ -*- c++ -*-
+//$Id: button-canvas.h,v 1.3 2001/10/18 19:08:51 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -35,7 +35,7 @@ namespace Guikachu
 	    public:
 		ButtonCanvasItem (Widgets::Button  *widget,
 				  FormEditor::Form *form);
-	    private:
+	    protected:
 		virtual void update ();
 	    };
 	}
