@@ -1,4 +1,4 @@
-//$Id: button.h,v 1.11 2001/10/02 21:47:04 cactus Exp $ -*- c++ -*-
+//$Id: button.h,v 1.12 2001/10/23 13:05:51 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -60,14 +60,15 @@ namespace Guikachu
 	    virtual GUI::FormEditor::CanvasItem *create_canvas_item (GUI::FormEditor::Form *form);
 	    virtual Gtk::Widget                 *create_editor ();
 
-	    virtual int get_display_width ();
-	    virtual int get_display_height ();
-
 	    Property<ButtonFrameType> frame;
 
 	    Property<bool>            usable;
 	    Property<bool>            repeat;
 	    Property<bool>            anchor_right;
+
+	protected:
+	    virtual int get_auto_width ();
+	    virtual int get_auto_height ();
 	    
 	private:
 	    // Persistance
