@@ -1,4 +1,4 @@
-//$Id: canvasitem.cc,v 1.10 2001/09/19 21:13:56 cactus Exp $ -*- c++ -*-
+//$Id: canvasitem.cc,v 1.15 2001/10/21 20:47:40 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -21,10 +21,12 @@
 #include "config.h"
 #include <libgnome/libgnome.h>
 
-#include <gnome--/app-helper.h>
 #include <gnome--/canvas-rect.h>
+#include <gnome--/app-helper.h>
 #include <libgnomeui/gnome-stock.h>
+
 #include <list>
+#include <math.h>
 
 #include "form-editor.h"
 
@@ -41,21 +43,14 @@ CanvasItem::CanvasItem (Widgets::Widget  *widget_,
     drag_context.dragging = false;
     drag_context.drag_occured = false;
     
-    using namespace Gnome;
-    
-    list <UI::Info> popup_menu_list;
-    /*
+    // Popup menu
+    list <Gnome::UI::Info> popup_menu_list;
     popup_menu_list.push_back (
-	UI::Item (_("Move"),
-		  SigC::slot (this, &CanvasItem::move_cb)));
-    */
-    popup_menu_list.push_back (
-	UI::Item (UI::Icon (GNOME_STOCK_PIXMAP_TRASH),
-		  _("Remove"),
-		  SigC::slot (this, &CanvasItem::remove_cb)));
+	Gnome::UI::Item (Gnome::UI::Icon (GNOME_STOCK_PIXMAP_TRASH),
+			 _("Remove"), menu_remove.slot ()));
+    
+    Gnome::UI::fill (popup_menu, popup_menu_list, *(popup_menu.get_accel_group ()));
     
-    UI::fill (popup_menu, popup_menu_list, *(popup_menu.get_accel_group ()));
-
     widget->changed.connect  (SigC::slot (this, &CanvasItem::update));
     widget->selected.connect (SigC::slot (this, &CanvasItem::widget_selected_cb));
 }
@@ -78,58 +73,6 @@ void CanvasItem::set_canvas_item (Gnome::CanvasGroup *item_)
     widget_selected_cb (selected);
 }
 
-void CanvasItem::remove_cb ()
-{
-    widget->get_form ()->remove_widget (widget);
-}
-
-void CanvasItem::move_cb ()
-{
-#if 0
-    GdkEvent *event = gdk_event_get ();
-
-    cerr << event->motion.x << endl << event->motion.y << endl;
-    
-    switch (event->type) {
-    case GDK_ENTER_NOTIFY:
-    case GDK_LEAVE_NOTIFY:
-	item->get_canvas ()->window_to_world (event->crossing.x, event->crossing.y,
-					      event->crossing.x, event->crossing.y);
-	break;
-	
-    case GDK_MOTION_NOTIFY:
-    case GDK_BUTTON_PRESS:
-    case GDK_2BUTTON_PRESS:
-    case GDK_3BUTTON_PRESS:
-    case GDK_BUTTON_RELEASE:
-	item->get_canvas ()->window_to_world (event->motion.x, event->motion.y,
-					      event->motion.x, event->motion.y);
-	break;
-	
-    default:
-	break;
-    }
-    
-    cerr << event->motion.x << endl << event->motion.y << endl;
-    
-    drag_begin (event);
-#else
-    GdkEvent event;
-
-    int pointer_x, pointer_y;
-
-    gdk_window_get_pointer (item->get_canvas ()->get_window (),
-			    &pointer_x,
-			    &pointer_y,
-			    0);
-    item->get_canvas ()->window_to_world (pointer_x, pointer_y,
-					  event.button.x, event.button.y);
-    event.button.time = GDK_CURRENT_TIME;
-    
-    drag_begin (&event);
-#endif
-}
-
 int CanvasItem::canvas_event_cb (GdkEvent *e)
 {
     /*
@@ -141,18 +84,18 @@ int CanvasItem::canvas_event_cb (GdkEvent *e)
     if (e->type == GDK_BUTTON_PRESS &&
 	e->button.button == 1 &&
 	!drag_context.dragging)
-	drag_begin (e);
+	drag_begin_impl (e);
     
     // Dragging
     if (e->type == GDK_MOTION_NOTIFY &&
 	drag_context.dragging)
-	drag_motion (e);
+	drag_motion_impl (e);
 
     // Ending drag
     if (e->type == GDK_BUTTON_RELEASE &&
 	(e->button.button == 1) &&
 	drag_context.dragging)
-	drag_end (e);
+	drag_end_impl (e);
     
 
     // Single click
@@ -164,31 +107,34 @@ int CanvasItem::canvas_event_cb (GdkEvent *e)
     // Context menu
     if ((e->type == GDK_BUTTON_PRESS) &&
 	(e->button.button == 3))
-    {
 	popup_menu.popup (e->button.button, e->button.time);
-    }
     
     return TRUE;
 }
 
-void CanvasItem::drag_begin (GdkEvent *e)
+void CanvasItem::drag_begin_impl (GdkEvent *e)
 {
     drag_context.dragging = true;
     drag_context.drag_occured = false;
 
-    drag_context.last_x = e->button.x;
-    drag_context.last_y = e->button.y;
+    drag_context.last_x = drag_context.start_x = e->button.x;
+    drag_context.last_y = drag_context.start_y = e->button.y;
     
     drag_context.offset_x = drag_context.last_x - widget->x;
     drag_context.offset_y = drag_context.last_y - widget->y;
+
+    drag_context.delta_remainder_x = 0;
+    drag_context.delta_remainder_y = 0;
     
     Gdk_Cursor cursor (gdk_cursor_new (GDK_FLEUR));
     item->grab (GDK_POINTER_MOTION_MASK | GDK_BUTTON_MOTION_MASK |
 		GDK_BUTTON_RELEASE_MASK | GDK_BUTTON_PRESS_MASK,
 		cursor, e->button.time);
+
+    drag_begin.emit ();
 }
 
-void CanvasItem::drag_motion (GdkEvent *e)
+void CanvasItem::drag_motion_impl (GdkEvent *e)
 {
     drag_context.drag_occured = true;
     
@@ -210,26 +156,39 @@ void CanvasItem::drag_motion (GdkEvent *e)
     // North bound
     if ((curr_y - drag_context.offset_y) < 0)
 	curr_y = drag_context.offset_y;
-    
-    item->move (curr_x - drag_context.last_x,
-		curr_y - drag_context.last_y);
+
+    // Remainders need to be collected
+    double dx = (curr_x - drag_context.last_x) + drag_context.delta_remainder_x;
+    double dy = (curr_y - drag_context.last_y) + drag_context.delta_remainder_y;
+
+    drag_context.delta_remainder_x = fmod (dx, 1.0);
+    drag_context.delta_remainder_y = fmod (dy, 1.0);
     
     drag_context.last_x = curr_x;
     drag_context.last_y = curr_y;     
+
+    drag_motion.emit (dx / 1, dy / 1);
 }
 
-void CanvasItem::drag_end (GdkEvent *e)
+void CanvasItem::drag_end_impl (GdkEvent *e)
 {
     item->ungrab (e->button.time);
     drag_context.dragging = false;
     
     if (drag_context.drag_occured)
     {
-	widget->x = (int)(drag_context.last_x - drag_context.offset_x);
-	widget->y = (int)(drag_context.last_y - drag_context.offset_y);
+	int dx = (int)(drag_context.last_x - drag_context.start_x - drag_context.delta_remainder_x);
+	int dy = (int)(drag_context.last_y - drag_context.start_y - drag_context.delta_remainder_y);
+
+	drag_end.emit (dx, dy);
     }
 }
 
+void CanvasItem::move (int dx, int dy)
+{
+    item->move (dx, dy);
+}
+
 void CanvasItem::widget_selected_cb (bool selected_)
 {
     selected = selected_;
@@ -246,21 +205,33 @@ void CanvasItem::widget_selected_cb (bool selected_)
 
     delete bounding_box;
     bounding_box = create_bounding_box ();
+    item->raise_to_top ();
 }
 
 Gnome::CanvasItem * CanvasItem::create_bounding_box ()
 {
-    double x1, x2, y1, y2;
-
-    item->get_bounds (x1, y1, x2, y2);
+    int x1, y1, x2, y2;
+    
+    get_bounds (x1, y1, x2, y2);
 
     using namespace Gnome::CanvasHelpers;
-    Gnome::CanvasItem *bounding_box = new Gnome::CanvasRect (*item,
-							     x1 - 2, y1 - 2,
-							     x2 + 2, y2 + 2);
+    Gnome::CanvasItem *bounding_box = new Gnome::CanvasRect (*item, x1, y1, x2, y2);
     *bounding_box
 	<< width_units (2)
 	<< outline_color (GUIKACHU_SELECTED);
 
     return bounding_box;
 }
+
+void CanvasItem::get_bounds (int &x1, int &y1,
+			     int &x2, int &y2)
+{
+    double x1_, y1_, x2_, y2_;
+    
+    item->get_bounds (x1_, y1_, x2_, y2_);
+
+    x1 = (int)x1_ - 2;
+    y1 = (int)y1_ - 2;
+    x2 = (int)x2_ + 2;
+    y2 = (int)y2_ + 2;
+}
