@@ -1,4 +1,4 @@
-//$Id: checkbox-canvas.cc,v 1.11 2001/09/20 16:15:57 cactus Exp $ -*- c++ -*-
+//$Id: checkbox-canvas.cc,v 1.12 2001/10/18 19:08:51 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -21,6 +21,7 @@
 #include "form-editor.h"
 
 #include <gnome--/canvas-polygon.h>
+#include <gnome--/canvas-rect.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <gdk-pixbuf/gnome-canvas-pixbuf.h>
 
@@ -106,3 +107,18 @@ void CheckboxCanvasItem::update ()
     
     set_canvas_item (group);
 }
+
+void CheckboxCanvasItem::get_bounds (int &x1, int &y1,
+				     int &x2, int &y2)
+{
+    int width = widget->get_display_width ();
+    int height = widget->get_display_height ();
+
+    width = MAX (18, width);
+    height = MAX (10, height);
+    
+    x1 = widget->x - 1;
+    x2 = x1 + width + 1 + 1;
+    y1 = widget->y - 1;
+    y2 = y1 + height + 1;
+}
