@@ -1,4 +1,4 @@
-//$Id: form-editor.h,v 1.9 2001/07/05 22:25:14 cactus Exp $ -*- c++ -*-
+//$Id: form-editor.h,v 1.11 2001/09/22 18:54:11 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -19,9 +19,11 @@
 #ifndef GUIKACHU_FORM_EDITOR_H
 #define GUIKACHU_FORM_EDITOR_H
 
-#define GUIKACHU_BGC "#90B398"
-#define GUIKACHU_FGC "black"   
+#define GUIKACHU_BGC          "#90B398"
+#define GUIKACHU_FGC          "black"   
 #define GUIKACHU_FGC_DISABLED "#505050"
+#define GUIKACHU_SELECTED     "#ecffa8"
+
 
 #define GUIKACHU_SCREEN_WIDTH 160
 #define GUIKACHU_SCREEN_HEIGHT 160
@@ -37,8 +39,8 @@ namespace Guikachu
     {
 	namespace FormEditor
 	{
-	    Font &get_font (int font_num);
-	    Font &get_title_font ();
+	    const Font &get_font (int font_num);
+	    const Font &get_title_font ();
 	    
 	    unsigned int get_font_height (int font_num);
 	    unsigned int get_string_width (int font_num, const string& text);
