@@ -1,4 +1,4 @@
-//$Id: form-prop.cc,v 1.11 2001/09/07 21:28:34 cactus Exp $ -*- c++ -*-
+//$Id: form-prop.cc,v 1.12 2001/10/23 13:05:51 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -24,6 +24,7 @@
 #include "widgets/entry.h"
 #include "widgets/num-entry.h"
 #include "widgets/pos-entry.h"
+#include "widgets/size-entry.h"
 #include "widgets/togglebutton.h"
 #include "widgets/widget-combo.h"
 #include "widgets/resource-combo.h"
@@ -88,12 +89,12 @@ FormProperties::FormProperties (Resources::Form *res_):
 		      "to the screen"));
 
     /* Width */
-    control = new GUI::PosEntry (res->width);
+    control = new GUI::SizeEntry (res->width);
     proptable->add (_("_Width:"), *manage (control),
 		    _("Horizontal size of the form"));
 
     /* Height */
-    control = new GUI::PosEntry (res->height);
+    control = new GUI::SizeEntry (res->height);
     proptable->add (_("_Height:"), *manage (control),
 		    _("Vertical size of the form"));
     
