@@ -1,4 +1,4 @@
-//$Id: form.cc,v 1.21 2001/09/22 19:21:42 cactus Exp $ -*- c++ -*-
+//$Id: form.cc,v 1.23 2001/10/20 16:06:51 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -70,7 +70,7 @@ Form::~Form ()
 {
 }
 
-Gnome::CanvasGroup *Form::get_canvas () const
+Gnome::CanvasGroup * Form::get_canvas () const
 {
     return widget_group;
 }
@@ -84,37 +84,6 @@ void Form::update ()
     group->set_y (res->y);
 
     widget_group->raise_to_top ();
-    
-#if 0
-    /* Reset canvas group */
-    if (widget_group)
-	delete widget_group;
-    widget_group = new Gnome::CanvasGroup (*group, 0, 0);
-
-#if 0
-    /* FIXME: This looks like my ass
-     * But I can't really find a feasible solution to bind the
-     * lifetime of Guikachu::GUI::FormEditor::CanvasItems to
-     * the lifetime of their underlying Gnome::CanvasItem.
-     */
-    static list<CanvasItem*> canvas_item_list;
-    for (list<CanvasItem*>::iterator i = canvas_item_list.begin ();
-	 i != canvas_item_list.end (); i++)
-	delete *i;
-    canvas_item_list.clear ();
-    
-    set<Widgets::Widget*> wset = res->get_widgets ();
-    for (set<Widgets::Widget*>::iterator i = wset.begin ();
-	 i != wset.end (); i++)
-    {
-	using namespace SigC;
-	
-	CanvasItem *canvas_item = (*i)->get_canvas_item (this);
-	canvas_item->clicked.connect (bind (slot (this, &Form::widget_clicked_cb), *i));
-	canvas_item_list.push_back (canvas_item);
-    }
-#endif
-#endif
 }
 
 Gtk::Widget* Form::get_editor ()
@@ -367,3 +336,6 @@ int Form::canvas_event_cb (GdkEvent *e)
     return true;
 }
 
+void Form::selected_cb (bool selected)
+{
+}
