@@ -1,4 +1,4 @@
-//$Id: form.h,v 1.8 2001/09/18 22:28:47 cactus Exp $ -*- c++ -*-
+//$Id: form.h,v 1.10 2001/10/20 16:06:51 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -54,6 +54,8 @@ namespace Guikachu
 		Gnome::CanvasGroup *frame_group;
 		Gnome::CanvasGroup *title_group;
 		Gnome::CanvasGroup *widget_group;
+		Gnome::CanvasItem  *bounding_box;
+
 	    public:
 		Form (Resources::Form *res,
 		      GUI::FormWindow *win);
@@ -61,7 +63,10 @@ namespace Guikachu
 		Gtk::Widget *get_editor ();
 		
 		Gnome::CanvasGroup *get_canvas () const;
-		SigC::Signal0<void> clicked;
+		
+		SigC::Signal0<void>       clicked;
+		SigC::Signal1<void, bool> selected;
+		
 	    private:
 		void update ();
 		
@@ -75,7 +80,8 @@ namespace Guikachu
 		void draw_title_nonmodal ();
 		
 		/* Callbacks */
-		int canvas_event_cb (GdkEvent *e);
+		int  canvas_event_cb (GdkEvent *e);
+		void selected_cb (bool selected);
 	    };
 	}
     }
