@@ -1,4 +1,4 @@
-//$Id: label.h,v 1.12 2001/09/18 22:28:47 cactus Exp $ -*- c++ -*-
+//$Id: label.h,v 1.13 2001/10/02 21:47:04 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -19,12 +19,6 @@
 #ifndef GUIKACHU_FORM_EDITOR_LABEL_H
 #define GUIKACHU_FORM_EDITOR_LABEL_H
 
-#include <string>
-#include <iostream>
-#include <gnome-xml/tree.h>
-#include <sigc++/basic_signal.h>
-#include "widget.h"
-
 namespace Guikachu
 {
     namespace Widgets
@@ -33,6 +27,7 @@ namespace Guikachu
     }
 }
 
+#include "widget.h"
 #include "resource.h"
 #include "textual.h"
 
