@@ -1,4 +1,4 @@
-//$Id: list.cc,v 1.10 2001/09/18 22:28:47 cactus Exp $ -*- c++ -*-
+//$Id: list.cc,v 1.12 2001/10/09 16:37:13 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -27,7 +27,7 @@ using namespace Guikachu::GUI::FormEditor;
 List::List (Resources::Form *owner,
 	    const string& id):
     Widget (owner, id),
-    
+    editor (0),
     font (changed, 0),
     visible_items (changed, 4),
     usable (changed, true),
@@ -35,16 +35,19 @@ List::List (Resources::Form *owner,
     width (changed, 1),
     manual_width (changed, false)
 {
-    editor = new ListProperties (this);
 }
 
 List::~List ()
 {
-    delete editor;
+    if (editor)
+	delete editor;
 }
 
 Gtk::Widget *List::create_editor ()
 {
+    if (!editor)
+	editor = new ListProperties (this);
+    
     return editor->get_editor ();
 }
 
@@ -135,7 +138,7 @@ void List::save (StorageNode &node) const
     my_node.set_prop ("font", font);
     my_node.set_prop ("visible", visible_items);
     
-    vector<string> items_vec = items;
+    const vector<string> &items_vec = items;
     for (vector<string>::const_iterator i = items_vec.begin ();
 	 i != items_vec.end (); i++)
 	my_node.add_node ("item", *i);
@@ -151,7 +154,7 @@ void List::save_rcp (ostream &ostr) const
 	width_str = g_strdup ("AUTO");
     
     ostr << "  LIST";
-    vector<string> items_vec = items ();
+    const vector<string> &items_vec = items;
     for (vector<string>::const_iterator i = items_vec.begin ();
 	 i != items_vec.end (); i++)
 	ostr << " \"" << *i << "\"";
