@@ -1,4 +1,4 @@
-//$Id: palette.cc,v 1.9 2001/10/02 21:47:04 cactus Exp $ -*- c++ -*-
+//$Id: palette.cc,v 1.11 2001/10/19 11:14:33 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -40,20 +40,23 @@ Palette::Palette ():
     inside_button_cb (false)
 {
     set_title (_("Widget palette"));
-    set_policy (false, false, false);
+    set_policy (false, true, false);
 
     using namespace SigC;
 
     Gtk::VBox *vbox = new Gtk::VBox;
-    Gtk::HBox *hbox = new Gtk::HBox;
+    Gtk::HBox *hbox = new Gtk::HBox (false, 5);
 
     Gtk::ToggleButton *button_none;
 
     button_none = create_button (Widgets::WIDGET_NONE, _("Selector"), none_xpm);
+    current_widget_name.set_alignment (0, 0.5);
+    current_widget_name.set_usize (10, -1);
     
     hbox->pack_start (*manage (button_none), false, false);
-    vbox->add (*manage (hbox));
-    vbox->add (*manage (new Gtk::HSeparator));
+    hbox->pack_start (current_widget_name, true, true);
+    vbox->pack_start (*manage (hbox), false, false);
+    vbox->pack_start (*manage (new Gtk::HSeparator), false, false);
     
     Gtk::Table *table = new Gtk::Table (3, 5);
 
@@ -76,7 +79,7 @@ Palette::Palette ():
 		       _("Clickable button"),
 		       0, 1);
     PALETTE_ADD_BUTTON(Widgets::WIDGET_PUSHBUTTON,
-		       _("Pushbutton"),
+		       _("Togglable button"),
 		       1, 1);
     PALETTE_ADD_BUTTON(Widgets::WIDGET_SELECTOR_TRIGGER,
 		       _("Selector trigger"),
@@ -105,16 +108,22 @@ Palette::Palette ():
     PALETTE_ADD_BUTTON(Widgets::WIDGET_TABLE,
 		       _("Multi-column table"),
 		       1, 3);
+
+    PALETTE_ADD_BUTTON(Widgets::WIDGET_GADGET,
+		       _("Custom widget"),
+		       0, 4);
 		       
 #undef PALETTE_ADD_BUTTON
 
     vbox->add (*manage (table));
 
     add (*manage (vbox));
+
+    set_selection (Widgets::WIDGET_NONE);
 }
 
 Gtk::ToggleButton * Palette::create_button (Widgets::Type       type,
-					    const string&       tooltip,
+					    const string       &tooltip,
 					    const char * const *icon_xpm)
 {
     using namespace SigC;
@@ -148,6 +157,9 @@ int Palette::delete_event_impl (GdkEventAny *e)
 
 void Palette::widget_button_cb (Widgets::Type type)
 {
+    if (inside_button_cb)
+	return;
+    
     GdkModifierType modifiers;
     int dummy;
     
@@ -173,7 +185,9 @@ void Palette::set_selection (Widgets::Type type)
 	    (*i)->set_active (false);
     }
 
+    current_widget_name.set_text (Widgets::display_name_from_type (type));
+    
     inside_button_cb = false;
-
+    
     palette_changed (type);
 }
