@@ -1,4 +1,4 @@
-//$Id: palette.h,v 1.4 2001/09/16 19:51:26 cactus Exp $ -*- c++ -*-
+//$Id: palette.h,v 1.5 2001/10/16 16:11:49 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -32,6 +32,7 @@ namespace Guikachu
 #include <gtk--/window.h>
 #include <gtk--/tooltips.h>
 #include <gtk--/togglebutton.h>
+#include <gtk--/label.h>
 
 #include <list>
 
@@ -42,6 +43,7 @@ namespace Guikachu
 	class Palette: public Gtk::Window
 	{
 	    Gtk::Tooltips            tips;
+	    Gtk::Label               current_widget_name;
 	    list<Gtk::ToggleButton*> buttons;
 	    bool                     sticky;
 	public:
@@ -52,7 +54,7 @@ namespace Guikachu
 	    
 	private:
 	    Gtk::ToggleButton* create_button (Widgets::Type       type,
-					      const string&       tooltip,
+					      const string       &tooltip,
 					      const char * const *icon_xpm);
 
 	    int  delete_event_impl (GdkEventAny *e);
