@@ -1,4 +1,4 @@
-//$Id: popup-trigger-canvas.cc,v 1.5 2001/09/19 21:13:56 cactus Exp $ -*- c++ -*-
+//$Id: popup-trigger-canvas.cc,v 1.7 2001/10/20 16:06:51 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -21,6 +21,7 @@
 #include "form-editor.h"
 
 #include <gnome--/canvas-polygon.h>
+#include <gnome--/canvas-rect.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <gdk-pixbuf/gnome-canvas-pixbuf.h>
 
@@ -74,3 +75,12 @@ void PopupTriggerCanvasItem::update ()
 
     set_canvas_item (group);
 }
+
+void PopupTriggerCanvasItem::get_bounds (int &x1, int &y1,
+					 int &x2, int &y2)
+{
+    x1 = widget->x;
+    x2 = x1 + widget->get_display_width () + 15 + 2;
+    y1 = widget->y - 1;
+    y2 = y1 + widget->get_display_height () +2;
+}
