@@ -1,4 +1,4 @@
-//$Id: popup-trigger.cc,v 1.9 2001/10/07 13:06:19 cactus Exp $ -*- c++ -*-
+//$Id: popup-trigger.cc,v 1.10 2001/10/23 13:05:51 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -183,20 +183,12 @@ void PopupTrigger::save_rcp (ostream &ostr) const
     g_free (width_str);
 }
 
-int PopupTrigger::get_display_width ()
+int PopupTrigger::get_auto_width ()
 {
-    if (manual_width)
-	return width;
-
-    int text_width = get_string_width (font, text);
-    return text_width;
+    return get_string_width (font, text);
 }
 
-int PopupTrigger::get_display_height ()
+int PopupTrigger::get_auto_height ()
 {
-    if (manual_height)
-	return height;
-
-    int text_height = get_font_height (font);
-    return text_height;
+    return get_font_height (font);
 }
