@@ -1,4 +1,4 @@
-//$Id: pushbutton-canvas.cc,v 1.9 2001/09/19 21:13:56 cactus Exp $ -*- c++ -*-
+//$Id: pushbutton-canvas.cc,v 1.11 2001/10/18 19:08:51 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -81,3 +81,12 @@ void PushButtonCanvasItem::update ()
 
     set_canvas_item (group);
 }
+
+void PushButtonCanvasItem::get_bounds (int &x1, int &y1,
+				       int &x2, int &y2)
+{
+    x1 = widget->x - 1;
+    x2 = x1 + widget->get_display_width () + 1;
+    y1 = widget->y - 1;
+    y2 = y1 + widget->get_display_height () + 2;
+}
