@@ -1,4 +1,4 @@
-//$Id: pushbutton.cc,v 1.11 2001/10/07 13:06:19 cactus Exp $ -*- c++ -*-
+//$Id: pushbutton.cc,v 1.12 2001/10/23 13:05:51 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -171,21 +171,14 @@ void PushButton::save_rcp (ostream &ostr) const
     g_free (width_str);
 }
 
-int PushButton::get_display_width ()
+int PushButton::get_auto_width ()
 {
-    if (manual_width)
-	return width;
-    
     int text_width = get_string_width (font, text);
 
     return 2 + text_width + 2;
 }
 
-int PushButton::get_display_height ()
+int PushButton::get_auto_height ()
 {
-    if (manual_height)
-	return height;
-
-    int text_height = get_font_height (font);
-    return text_height;
+    return get_font_height (font);
 }
