@@ -1,4 +1,4 @@
-//$Id: scrollbar-prop.cc,v 1.3 2001/09/07 21:03:08 cactus Exp $ -*- c++ -*-
+//$Id: scrollbar-prop.cc,v 1.4 2001/09/27 22:23:46 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -31,7 +31,8 @@
 using namespace Guikachu::GUI::FormEditor;
 using namespace Guikachu::Widgets;
 
-ScrollBarProperties::ScrollBarProperties (ScrollBar *res)
+ScrollBarProperties::ScrollBarProperties (ScrollBar *res_):
+    res (res_)
 {
     using namespace Gtk;
     using namespace SigC;
@@ -79,6 +80,8 @@ ScrollBarProperties::ScrollBarProperties (ScrollBar *res)
     proptable->show ();
     property_editor = manage (proptable);
     gtk_object_ref (GTK_OBJECT (property_editor->gtkobj ()));
+
+    res->changed.connect (SigC::slot (this, &ScrollBarProperties::update));
 }
 
 ScrollBarProperties::~ScrollBarProperties ()
@@ -90,3 +93,9 @@ Gtk::Widget* ScrollBarProperties::get_editor ()
 {
     return property_editor;
 }
+
+void ScrollBarProperties::update ()
+{
+    value->set_min (res->min_value);
+    value->set_max (res->max_value);
+}
