@@ -1,4 +1,4 @@
-//$Id: scrollbar.h,v 1.6 2001/10/02 21:47:04 cactus Exp $ -*- c++ -*-
+//$Id: scrollbar.h,v 1.7 2001/10/23 13:05:51 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -50,11 +50,12 @@ namespace Guikachu
 	    virtual GUI::FormEditor::CanvasItem *create_canvas_item (GUI::FormEditor::Form *form);
 	    virtual Gtk::Widget                 *create_editor ();
 
-	    virtual int get_display_width ();
-	    virtual int get_display_height ();
-
 	    Property<bool> usable;
 	    Property<int>  min_value, max_value, value, page_size;
+
+	protected:
+	    virtual int get_auto_width  ();
+	    virtual int get_auto_height ();
 	    
 	private:
 	    // Persistance
