@@ -1,4 +1,4 @@
-//$Id: selector-trigger-canvas.cc,v 1.11 2001/09/22 19:07:54 cactus Exp $ -*- c++ -*-
+//$Id: selector-trigger-canvas.cc,v 1.13 2001/10/19 11:14:33 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -63,7 +63,7 @@ void SelectorTriggerCanvasItem::update ()
 
     /* Data for the GdkBitmap to use as an outline stipple */
     static const char stipple_bits[] = {
-	0x01, 0x02, };
+	0x02, 0x01, };
 
     Gnome::CanvasPolygon *frame_item = new Gnome::CanvasPolygon (*group, frame_points);    
     frame_item->set_width_units (1);
@@ -91,3 +91,15 @@ void SelectorTriggerCanvasItem::update ()
 
     set_canvas_item (group);
 }
+
+void SelectorTriggerCanvasItem::get_bounds (int &x1, int &y1,
+					    int &x2, int &y2)
+{
+    int width = widget->get_display_width ();
+    int height = widget->get_display_height ();
+    
+    x1 = widget->x;
+    x2 = x1 + width + 1;
+    y1 = widget->y;
+    y2 = y1 + height + 1;
+}
