@@ -1,4 +1,4 @@
-//$Id: selector-trigger.cc,v 1.10 2001/10/07 13:06:19 cactus Exp $ -*- c++ -*-
+//$Id: selector-trigger.cc,v 1.11 2001/10/23 13:05:51 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -174,21 +174,14 @@ void SelectorTrigger::save_rcp (ostream &ostr) const
     g_free (width_str);
 }
 
-int SelectorTrigger::get_display_width ()
+int SelectorTrigger::get_auto_width ()
 {
-    if (manual_width)
-	return width;
-
     int text_width = get_string_width (font, text);
     return 2 + text_width + 2;
 }
 
-int SelectorTrigger::get_display_height ()
+int SelectorTrigger::get_auto_height ()
 {
-    if (manual_height)
-	return height;
-
     int text_height = get_font_height (font);
     return text_height + 1;
-
 }
