@@ -1,4 +1,4 @@
-//$Id: text-field-canvas.cc,v 1.1 2001/09/22 19:21:42 cactus Exp $ -*- c++ -*-
+//$Id: text-field-canvas.cc,v 1.2 2001/10/18 20:41:42 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -93,3 +93,12 @@ void TextFieldCanvasItem::update ()
     
     set_canvas_item (group);
 }
+
+void TextFieldCanvasItem::get_bounds (int &x1, int &y1,
+				      int &x2, int &y2)
+{
+    x1 = widget->x;
+    x2 = x1 + widget->get_display_width ();
+    y1 = widget->y;
+    y2 = y1 + widget->get_display_height ();
+}
