@@ -1,4 +1,4 @@
-//$Id: text-field.cc,v 1.2 2001/10/07 13:06:19 cactus Exp $ -*- c++ -*-
+//$Id: text-field.cc,v 1.3 2001/10/23 13:05:51 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -246,20 +246,22 @@ void TextField::save_rcp (ostream &ostr) const
     g_free (width_str);
 }
 
-int TextField::get_display_width ()
+int TextField::get_auto_width ()
 {
-    if (manual_width)
-	return width;
-
     return 30;
 }
 
 int TextField::get_display_height ()
 {
-    int min_height = get_font_height (font);
+    int min_height = get_auto_height ();
     
     if (manual_height && height > min_height)
 	return height;
     
     return min_height;
 }
+
+int TextField::get_auto_height ()
+{
+    return get_font_height (font);
+}
