@@ -1,4 +1,4 @@
-//$Id: text-field.h,v 1.2 2001/10/02 21:47:04 cactus Exp $ -*- c++ -*-
+//$Id: text-field.h,v 1.3 2001/10/23 13:05:51 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -50,9 +50,6 @@ namespace Guikachu
 	    virtual GUI::FormEditor::CanvasItem *create_canvas_item (GUI::FormEditor::Form *form);
 	    virtual Gtk::Widget                 *create_editor ();
 
-	    virtual int get_display_width ();
-	    virtual int get_display_height ();
-
 	    Property<bool> usable;
 
 	    Property<int>  font;
@@ -66,6 +63,13 @@ namespace Guikachu
 	    Property<bool> dynamic_size;
 	    Property<bool> justify_right;
 	    Property<bool> has_scrollbar;
+
+	protected:
+	    virtual int get_auto_width  ();
+	    virtual int get_auto_height ();
+
+	public:
+	    virtual int get_display_height ();
 	    
 	private:
 	    // Persistance
