@@ -1,4 +1,4 @@
-//$Id: widget-util.cc,v 1.4 2001/10/02 21:47:04 cactus Exp $ -*- c++ -*-
+//$Id: widget-util.cc,v 1.6 2001/10/19 11:14:33 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -18,6 +18,9 @@
 
 #include "form-editor/widget-util.h"
 
+#include "config.h"
+#include <libgnome/libgnome.h>
+
 using namespace Guikachu;
 
 namespace {
@@ -33,9 +36,10 @@ namespace {
 #include "pixmaps/scrollbar.xpm"
 #include "pixmaps/text-field.xpm"
 #include "pixmaps/table.xpm"
+#include "pixmaps/gadget.xpm"
 }
 
-string Widgets::type_id_from_type (Widgets::Type type)
+const string Widgets::type_id_from_type (Widgets::Type type)
 {
     g_return_val_if_fail (type != Widgets::WIDGET_NONE, "");
     
@@ -76,6 +80,9 @@ string Widgets::type_id_from_type (Widgets::Type type)
     case Widgets::WIDGET_TABLE:
 	type_id = "table";
 	break;
+    case Widgets::WIDGET_GADGET:
+	type_id = "gadget";
+	break;
     case Widgets::WIDGET_NONE:
 	g_assert_not_reached ();
 	break;
@@ -112,6 +119,8 @@ Widgets::Type Widgets::type_from_type_id (const string &type_id)
 	type = Widgets::WIDGET_TEXT_FIELD;
     else if (type_id == "table")
 	type = Widgets::WIDGET_TABLE;
+    else if (type_id == "gadget")
+	type = Widgets::WIDGET_GADGET;
     else
 	type = Widgets::WIDGET_NONE;
     
@@ -146,9 +155,61 @@ const char * const * Widgets::type_icon (Widgets::Type type)
 	return text_field_xpm;
     case Widgets::WIDGET_TABLE:
 	return table_xpm;
+    case Widgets::WIDGET_GADGET:
+	return gadget_xpm;
     case Widgets::WIDGET_NONE:
 	g_assert_not_reached ();
     }
 
     return NULL;
 }
+
+const string Widgets::display_name_from_type (Widgets::Type type)
+{
+    string disp_name;
+    
+    switch (type)
+    {
+    case Widgets::WIDGET_NONE:
+	disp_name = _("Selector");
+	break;
+    case Widgets::WIDGET_LABEL:
+	disp_name = _("Label");
+	break;
+    case Widgets::WIDGET_BUTTON:
+	disp_name = _("Button");
+	break;
+    case Widgets::WIDGET_PUSHBUTTON:
+	disp_name = _("Pushbutton");
+	break;
+    case Widgets::WIDGET_GRAFFITI:
+	disp_name = _("Graffiti");
+	break;
+    case Widgets::WIDGET_SELECTOR_TRIGGER:
+	disp_name = _("Selector trigger");
+	break;
+    case Widgets::WIDGET_CHECKBOX:
+	disp_name = _("Checkbox");
+	break;
+    case Widgets::WIDGET_LIST:
+	disp_name = _("List");
+	break;
+    case Widgets::WIDGET_POPUP_TRIGGER:
+	disp_name = _("Popup trigger");
+	break;
+    case Widgets::WIDGET_SCROLLBAR:
+	disp_name = _("Scrollbar");
+	break;
+    case Widgets::WIDGET_TEXT_FIELD:
+	disp_name = _("Text field");
+	break;
+    case Widgets::WIDGET_TABLE:
+	disp_name = _("Table");
+	break;
+    case Widgets::WIDGET_GADGET:
+	disp_name = _("Gadget");
+	break;
+    }
+    
+    return disp_name;
+}
