@@ -1,4 +1,4 @@
-//$Id: form-res.cc,v 1.22 2001/10/02 21:47:04 cactus Exp $ -*- c++ -*-
+//$Id: form-res.cc,v 1.23 2001/10/19 11:14:33 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -32,6 +32,7 @@
 #include "form-editor/scrollbar.h"
 #include "form-editor/text-field.h"
 #include "form-editor/table.h"
+#include "form-editor/gadget.h"
 
 using namespace Guikachu::Resources;
 using namespace Guikachu;
@@ -122,7 +123,11 @@ Widgets::Widget* Form::create_widget (Widgets::Type  type,
     case Widgets::WIDGET_TABLE:
 	widget = new Widgets::Table (this, id);
 	break;
+    case Widgets::WIDGET_GADGET:
+	widget = new Widgets::Gadget (this, id);
+	break;
     case Widgets::WIDGET_NONE:
+    default:
 	g_assert_not_reached ();
 	return 0;
 	break;
