@@ -1,4 +1,4 @@
-//$Id: form-win-helpers.cc,v 1.4 2001/08/18 14:23:01 cactus Exp $ -*- c++ -*-
+//$Id: form-win-helpers.cc,v 1.5 2001/09/19 19:25:15 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -21,10 +21,15 @@
 #include "config.h"
 #include <libgnome/libgnome.h>
 
+#include <gtk--/box.h>
+#include <gtk--/pixmap.h>
 #include <gnome--/app-helper.h>
 #include <libgnomeui/gnome-stock.h>
+
 #include <list>
 
+#include "form-editor/widget-util.h"
+
 using namespace Guikachu::GUI::FormWindow_Helpers;
 
 /***********************************
@@ -32,13 +37,23 @@ using namespace Guikachu::GUI::FormWindow_Helpers;
  ***********************************/
 
 WidgetTreeItem::WidgetTreeItem (Widgets::Widget *widget_):
-    Gtk::TreeItem (widget_->id),
     widget (widget_)
 {
     using namespace Gnome;
 
-    set_user_data (widget);
+    Gtk::Pixmap *pixmap = new Gtk::Pixmap (Widgets::type_icon (widget->get_type ()));
+    Gtk::Box    *box    = new Gtk::HBox   (false, 5);
+
+    label.set_alignment (0, 0.5);
+    box->pack_start (*manage (pixmap), false);
+    box->pack_start (label);
+    box->show_all ();
     
+    add (*manage (box));
+    
+
+    set_user_data (widget);
+
     list <UI::Info> popup_menu_list;
     popup_menu_list.push_back (
 	UI::Item (UI::Icon (GNOME_STOCK_PIXMAP_TRASH),
@@ -46,14 +61,16 @@ WidgetTreeItem::WidgetTreeItem (Widgets::Widget *widget_):
 		  SigC::slot (this, &WidgetTreeItem::remove_cb)));
     UI::fill (popup_menu, popup_menu_list, *(popup_menu.get_accel_group ()));
     
-    widget->changed.connect (slot (this, &WidgetTreeItem::update));
     button_press_event.connect (slot (this, &WidgetTreeItem::button_press_cb));
+    
+    widget->selected.connect (slot (this, &WidgetTreeItem::widget_selected_cb));
+    widget->changed.connect  (slot (this, &WidgetTreeItem::update));
+    update ();
 }
 
 void WidgetTreeItem::update ()
 {
-    remove ();
-    add_label (widget->id);
+    label.set_text (widget->id ());
 }
 
 int WidgetTreeItem::button_press_cb (GdkEventButton *e)
@@ -72,6 +89,13 @@ void WidgetTreeItem::remove_cb ()
     widget->get_form ()->remove_widget (widget);
 }
 
+void WidgetTreeItem::widget_selected_cb (bool selected)
+{
+    if (selected)
+	select ();
+    else
+	deselect ();
+}
 
 /***********************************
  * TopTreeItem
@@ -95,7 +119,7 @@ void TopTreeItem::update ()
 
 int TopTreeItem::button_press_cb (GdkEventButton *e)
 {
-    if (e->type == GDK_2BUTTON_PRESS && e->button == 1)
+    if (e->type == GDK_BUTTON_PRESS && e->button == 1)
 	activate ();
     
     return false;
