@@ -1,4 +1,4 @@
-//$Id: form-win-helpers.h,v 1.1 2001/04/02 22:46:38 cactus Exp $ -*- c++ -*-
+//$Id: form-win-helpers.h,v 1.2 2001/09/19 19:25:15 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -23,6 +23,7 @@
 
 #include <gtk--/treeitem.h>
 #include <gtk--/menu.h>
+#include <gtk--/label.h>
 
 namespace Guikachu
 {
@@ -34,6 +35,7 @@ namespace Guikachu
 	    {
 		Widgets::Widget *widget;
 		Gtk::Menu        popup_menu;
+		Gtk::Label       label;
 	    public:
 		WidgetTreeItem (Widgets::Widget *widget);
 		SigC::Signal0<void> activate;
@@ -41,6 +43,7 @@ namespace Guikachu
 		void update ();
 		void remove_cb ();
 		int button_press_cb (GdkEventButton *e);
+		void widget_selected_cb (bool selected);
 	    };
 	    
 	    class TopTreeItem: public Gtk::TreeItem
