@@ -1,4 +1,4 @@
-//$Id: form-win.cc,v 1.29 2001/09/19 20:30:53 cactus Exp $ -*- c++ -*-
+//$Id: form-win.cc,v 1.33 2001/10/21 20:47:40 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -47,9 +47,8 @@ static Guikachu::GUI::Palette *palette = 0;
 FormWindow::FormWindow (Form *res_):
     res (res_),
     edited_widget (0),
-    selected_widget (0),
     canvas_overlay (0),
-    selected_widget_type (Widgets::WIDGET_NONE)
+    palette_selection (Widgets::WIDGET_NONE)
 {
     gui = glade_xml_new (GLADEDIR "/guikachu.glade", 0);
 
@@ -59,30 +58,37 @@ FormWindow::FormWindow (Form *res_):
     window = wrap (GTK_WINDOW (glade_xml_get_widget (gui, "res_form")));
     window->delete_event.connect (slot (this, &FormWindow::delete_event_impl));
 
+    // Property editor window
     property_window = new Gtk::Window (GTK_WINDOW_DIALOG);
     property_window->set_title (_("Widget properties"));
     property_window->delete_event.connect (slot (this, &FormWindow::property_delete_event_impl));
     property_window->set_policy (false, true, true);
-    
+
+    // Load widgets from Glade file
     canvas = wrap (GNOME_CANVAS (glade_xml_get_widget (gui, "form_canvas")));
+    zoom_entry = wrap (GTK_SPIN_BUTTON (glade_xml_get_widget (gui, "form_zoom_entry")));
     Gtk::Tree *tree = wrap (GTK_TREE (glade_xml_get_widget (gui, "form_tree")));
-    tree->map_ (); // FIXME: Is this evil?
+    tree->map_ (); // FIXME: Isn't this evil?
+
+    // Zoom factor
+    Gtk::Adjustment *zoom_adj = zoom_entry->get_adjustment ();
+    zoom_adj->value_changed.connect (slot (this, &FormWindow::zoom_entry_cb));
     
+    // Widget tree
     FormWindow_Helpers::TopTreeItem *item = new FormWindow_Helpers::TopTreeItem (res);
     item->show ();
     item->activate.connect (slot (this, &FormWindow::form_clicked_cb));
     tree->add (*manage (item));
     top_treeitem = item;
-    
+
     form = new FormEditor::Form (res, this);
     form->clicked.connect (slot (this, &FormWindow::form_clicked_cb));
     
-    // Initial widget tree
+    // Set up initial widgets
     const set<Widgets::Widget*>& widgets = res->get_widgets ();
     for (set<Widgets::Widget*>::const_iterator i = widgets.begin ();
 	 i != widgets.end (); i++)
 	widget_created_cb (*i);
-
     
     res->changed.connect (slot (this, &FormWindow::update));
     res->widget_created.connect (slot (this, &FormWindow::widget_created_cb));
@@ -97,7 +103,6 @@ FormWindow::FormWindow (Form *res_):
 
 FormWindow::~FormWindow ()
 {
-//    window->destroy ();
     gtk_widget_destroy (GTK_WIDGET (window->gtkobj ()));
     gtk_object_unref (GTK_OBJECT (gui));
 
@@ -159,7 +164,8 @@ void FormWindow::widget_created_cb (Widgets::Widget *widget)
 {
     g_return_if_fail (widget != 0);
 
-    using namespace SigC;
+    using SigC::bind;
+    using SigC::slot;
     
     widget->request_edit.connect (bind (
 	slot (this, &FormWindow::show_property_editor),
@@ -176,12 +182,15 @@ void FormWindow::widget_created_cb (Widgets::Widget *widget)
 
     // Add canvas item
     FormEditor::CanvasItem *canvas_item = widget->get_canvas_item (form);
+
     canvas_item->clicked.connect (bind (slot (this, &FormWindow::widget_clicked_cb), widget));
+    canvas_item->menu_remove.connect (bind (slot (this, &FormWindow::widget_menu_remove_cb), widget));
+    
+    canvas_item->drag_motion.connect (slot (this, &FormWindow::widget_drag_motion_cb));
+    canvas_item->drag_end.connect (slot (this, &FormWindow::widget_drag_end_cb));
     
     FormWindow_Helpers::WidgetTreeItem *item = new FormWindow_Helpers::WidgetTreeItem (widget);
     item->show ();
-    // FIXME: clearly the selection stuff needs clearer
-    // model/view/controller separation
     item->activate.connect (bind (slot (this, &FormWindow::widget_clicked_cb), widget));
     
     tree->add (*item);
@@ -189,11 +198,12 @@ void FormWindow::widget_created_cb (Widgets::Widget *widget)
 
 void FormWindow::widget_removed_cb (Widgets::Widget *widget)
 {
-    if (widget == selected_widget)
-	selected_widget = 0;
-    
+    // Remove from selection
+    selected_widgets.erase (widget);
+
+    // Remove property editor
     if (widget == edited_widget)
-	form_clicked_cb ();
+	show_form_property_editor ();
     
     // Remove tree item
     Gtk::Tree::ItemList &itemlist = top_treeitem->get_subtree ()->tree ();
@@ -225,10 +235,10 @@ int FormWindow::canvas_overlay_cb (GdkEvent *event)
 
 void FormWindow::palette_cb (Widgets::Type type)
 {
-    if (type == selected_widget_type)
+    if (type == palette_selection)
 	return;
 
-    selected_widget_type = type;
+    palette_selection = type;
     delete canvas_overlay;
     canvas_overlay = 0;
     
@@ -266,7 +276,7 @@ void FormWindow::palette_cb (Widgets::Type type)
 
 void FormWindow::add_widget (int x, int y)
 {
-    Widgets::Widget *widget = res->create_widget (selected_widget_type);
+    Widgets::Widget *widget = res->create_widget (palette_selection);
 
     widget->x = x;
     widget->y = y;
@@ -321,12 +331,27 @@ void FormWindow::show_form_property_editor ()
 
 void FormWindow::form_clicked_cb ()
 {
-    if (selected_widget)
+    bool add_to_selection;
+    
     {
-	selected_widget->selected (false);
-	selected_widget = 0;
+	GdkModifierType modifiers;
+	int dummy;
+	
+	canvas->get_window ().get_pointer (dummy, dummy, modifiers);
+	add_to_selection = modifiers & GDK_CONTROL_MASK;
     }
 
+    if (add_to_selection)
+	return;
+    
+    for (set<Widgets::Widget*>::iterator i = selected_widgets.begin ();
+	 i != selected_widgets.end (); i++)
+    {
+	(*i)->selected (false);
+	selected_widgets.erase (i);
+    }
+    
+    form->selected (true);
     top_treeitem->select ();
    
     show_form_property_editor ();
@@ -334,13 +359,88 @@ void FormWindow::form_clicked_cb ()
 
 void FormWindow::widget_clicked_cb (Widgets::Widget *widget)
 {
-    if (selected_widget)
-	selected_widget->selected (false);
-    else
-	top_treeitem->deselect ();
+    bool add_to_selection;
+    
+    {
+	GdkModifierType modifiers;
+	int dummy;
+	
+	canvas->get_window ().get_pointer (dummy, dummy, modifiers);
+	add_to_selection = modifiers & GDK_CONTROL_MASK;
+    }
+
+    top_treeitem->deselect ();
+    form->selected (false);
+    widget->request_edit ();
+    
+    if (!add_to_selection)
+    {
+	if (selected_widgets.find (widget) != selected_widgets.end ())
+	    return;
+    
+	for (set<Widgets::Widget*>::iterator i = selected_widgets.begin ();
+	     i != selected_widgets.end (); i++)
+	{
+	    (*i)->selected (false);
+	    selected_widgets.erase (i);
+	}
+	
+    } else {
+
+	if (selected_widgets.find (widget) != selected_widgets.end ())
+	{
+	    selected_widgets.erase (widget);
+	    widget->selected (false);
+	    return;
+	}
+    }
     
     widget->selected (true);
-    selected_widget = widget;
+    selected_widgets.insert (widget);
+}
 
-    widget->request_edit ();
+void FormWindow::widget_menu_remove_cb (Widgets::Widget *widget)
+{
+    g_return_if_fail (widget);
+    
+    if (selected_widgets.size ())
+    {
+	for (set<Widgets::Widget*>::iterator i = selected_widgets.begin ();
+	     i != selected_widgets.end ();)
+	    res->remove_widget (*(i++));
+    } else {
+	res->remove_widget (widget);
+    }
+}
+
+void FormWindow::widget_drag_motion_cb (int dx, int dy)
+{
+    for (set<Widgets::Widget*>::iterator i = selected_widgets.begin ();
+	 i != selected_widgets.end (); i++)
+    {
+	FormEditor::CanvasItem *canvas_item = (*i)->get_canvas_item (form);
+	canvas_item->move (dx, dy);
+    }    
+}
+
+void FormWindow::widget_drag_end_cb (int dx, int dy)
+{
+    for (set<Widgets::Widget*>::iterator i = selected_widgets.begin ();
+	 i != selected_widgets.end (); i++)
+    {
+	(*i)->x += dx;
+	(*i)->y += dy;
+    }
+}
+
+void FormWindow::zoom_entry_cb ()
+{
+    float zoom_factor = zoom_entry->get_value_as_float ();
+    if (zoom_factor > GNOME_CANVAS_EPSILON)
+    {
+	canvas->set_pixels_per_unit (zoom_factor);
+	canvas->set_scroll_region (0, 0, GUIKACHU_SCREEN_WIDTH - 1,
+				   GUIKACHU_SCREEN_WIDTH - 1);
+	canvas->set_usize (160 * zoom_factor, GUIKACHU_SCREEN_WIDTH * zoom_factor);
+    }
 }
