@@ -1,4 +1,4 @@
-//$Id: form-win.h,v 1.17 2001/09/19 20:30:53 cactus Exp $ -*- c++ -*-
+//$Id: form-win.h,v 1.21 2001/10/21 20:47:40 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -33,7 +33,9 @@ namespace Guikachu
 
 #include <gtk--/window.h>
 #include <gtk--/tree.h>
+#include <gtk--/spinbutton.h>
 #include <gnome--/canvas.h>
+#include <set>
 
 #include <glade/glade-xml.h>
 
@@ -50,15 +52,16 @@ namespace Guikachu
 	    Gtk::Window                *property_window;
 	    
 	    Gnome::Canvas              *canvas;
+	    Gtk::SpinButton            *zoom_entry;
 	    Gtk::TreeItem              *top_treeitem;
 	    FormEditor::Form           *form;
 
 	    Widgets::Widget            *edited_widget;
-	    Widgets::Widget            *selected_widget;
+	    set<Widgets::Widget*>       selected_widgets;
 	    SigC::Connection            edited_widget_changed_conn;
-
+	    
 	    Gnome::CanvasItem          *canvas_overlay;
-	    Widgets::Type               selected_widget_type;
+	    Widgets::Type               palette_selection;
 	public:
 	    FormWindow (Resources::Form *res);
 	    ~FormWindow ();
@@ -71,6 +74,9 @@ namespace Guikachu
 
 	    int delete_event_impl (GdkEventAny *e);
 	    int property_delete_event_impl (GdkEventAny *e);
+
+	    void zoom_entry_cb ();
+	    
 	    void update ();
 	    void edited_widget_changed ();
 
@@ -80,9 +86,14 @@ namespace Guikachu
 
 	    void widget_created_cb (Widgets::Widget *widget);
 	    void widget_removed_cb (Widgets::Widget *widget);
+
+	    void widget_menu_remove_cb (Widgets::Widget *widget);
 	    
 	    void form_clicked_cb ();
 	    void widget_clicked_cb (Widgets::Widget *widget);
+
+	    void widget_drag_motion_cb (int dx, int dy);
+	    void widget_drag_end_cb    (int dx, int dy);
 	};
     };
 };
