@@ -1,4 +1,4 @@
-//$Id: property.h,v 1.5 2001/10/09 16:37:12 cactus Exp $ -*- c++ -*-
+//$Id: property.h,v 1.6 2001/10/20 16:06:50 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -72,6 +72,12 @@ namespace Guikachu
 	inline bool operator!= (const value_t &other) const { return value != other; };
 	inline bool operator!= (const self_t  &other) const { return value != other.value; };
 
+	inline value_t operator+= (const value_t &other) { set_val (value + other); return value; };
+	inline value_t operator+= (const self_t  &other) { set_val (value + other.value); return value; };
+
+	inline value_t operator-= (const value_t &other) { set_val (value - other); return value; };
+	inline value_t operator-= (const self_t  &other) { set_val (value - other.value); return value; };
+	
 	friend ostream & operator<<<value_t> (ostream &ostr, const Property<value_t> &prop);
     };
 
