@@ -1,4 +1,4 @@
-//$Id: resource-manager-io.cc,v 1.11 2001/09/16 13:06:06 cactus Exp $ -*- c++ -*-
+//$Id: resource-manager-io.cc,v 1.12 2001/10/19 20:17:56 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -112,6 +112,8 @@ Resources::Resource* ResourceManager::load_resource (StorageNode &node)
 	resource = create_resource (Resources::RESOURCE_MENU, id);
     else if (node_name == "string")
 	resource = create_resource (Resources::RESOURCE_STRING, id);
+    else if (node_name == "blob")
+	resource = create_resource (Resources::RESOURCE_BLOB, id);
     else
 	g_warning ("Unknown resource type `%s'", node_name.c_str ());
 
@@ -144,6 +146,9 @@ void ResourceManager::save (const string& filename)
 	case Resources::RESOURCE_STRING:
 	    curr_node_name = "string";
 	    break;
+	case Resources::RESOURCE_BLOB:
+	    curr_node_name = "blob";
+	    break;
 	case Resources::RESOURCE_DIALOG:
 	    curr_node_name = "dialog";
 	    break;
