@@ -1,4 +1,4 @@
-//$Id: resource-manager.cc,v 1.10 2001/10/10 16:17:45 cactus Exp $ -*- c++ -*-
+//$Id: resource-manager.cc,v 1.12 2001/10/20 16:06:50 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -19,11 +19,13 @@
 #include "resource-manager.h"
 
 #include "mainwin.h"
+#include "resource-util.h"
 
 #include "dialog-res.h"
 #include "form-res.h"
 #include "menu-res.h"
 #include "string-res.h"
+#include "blob-res.h"
 
 #include <fstream>
 #include <gnome-xml/parser.h>
@@ -83,9 +85,14 @@ void ResourceManager::unregister_id (const string& id)
     id_set.erase (id);
 }
 
-Resources::Resource* ResourceManager::create_resource (Resources::Type type,
-						       const string& id)
+Resources::Resource* ResourceManager::create_resource (Resources::Type  type,
+						       const string    &id_ = "")
 {
+    string id = id_;
+    
+    if (id == "")
+	id = create_id (Resources::type_id_from_type (type));
+    
     if (!register_id (id))
 	return 0;
 
@@ -107,6 +114,9 @@ Resources::Resource* ResourceManager::create_resource (Resources::Type type,
     case Resources::RESOURCE_STRING:
 	res = new Resources::String (real_id);
 	break;
+    case Resources::RESOURCE_BLOB:
+	res = new Resources::Blob (real_id);
+	break;
     case Resources::RESOURCE_MENU:
 	res = new Resources::Menu (real_id);
 	break;
@@ -131,12 +141,18 @@ Resources::Resource* ResourceManager::create_resource (Resources::Type type,
 bool ResourceManager::rename_resource (const string& old_id,
 				       const string& new_id)
 {
+    // No-ops: old_id == new_id
     if (old_id == new_id)
-	return false;
+	return true;
 
     if (string_case (old_id) == string_case (new_id))
 	return true;
-    
+
+    // Error: empty id
+    if (new_id == "")
+	return false;
+
+    // Error: old_id does not exist
     if (id_set.find (old_id) == id_set.end ())
 	return false;
 
