@@ -1,4 +1,4 @@
-//$Id: resource-manager.h,v 1.7 2001/09/16 13:06:06 cactus Exp $ -*- c++ -*-
+//$Id: resource-manager.h,v 1.8 2001/10/19 20:17:56 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -42,19 +42,19 @@ namespace Guikachu
 	static bool dirty;
 	static Resources::Application *app;
     public:
-	static Resources::Resource* create_resource (Resources::Type type,
-						     const string& id);
-	static void remove_resource (Resources::Resource* resource);
-	static bool rename_resource (const string& old_id,
-				     const string& new_id);
+	static Resources::Resource* create_resource (Resources::Type  type,
+						     const string    &id = "");
+	static void remove_resource (Resources::Resource *resource);
+	static bool rename_resource (const string &old_id,
+				     const string &new_id);
 
-	static bool register_id (const string& id);
-	static void unregister_id (const string& id);
+	static bool register_id   (const string &id);
+	static void unregister_id (const string &id);
 
-	static string create_id (const string& prefix);
+	static string create_id (const string &prefix);
 
 	static set<Resources::Resource*> get_resources ();
-	static Resources::Resource* get_resource (const string& id);
+	static Resources::Resource* get_resource (const string &id);
 	static Resources::Application* get_application () { return app; };
 	
 	// Signals
@@ -64,9 +64,9 @@ namespace Guikachu
 	// Persistance
 	static void reset ();
 	static bool is_dirty ();
-	static void load (const string& filename);
-	static void save (const string& filename);
-	static void export_rcp (const string& filename); 
+	static void load (const string &filename);
+	static void save (const string &filename);
+	static void export_rcp (const string &filename); 
 
     private:
 	static void resource_changed_cb ();
