@@ -1,4 +1,4 @@
-//$Id: resource.cc,v 1.3 2001/04/14 18:01:39 cactus Exp $ -*- c++ -*-
+//$Id: resource.cc,v 1.4 2001/08/18 14:23:01 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -20,18 +20,10 @@
 
 using namespace Guikachu;
 
-string Resources::Resource::get_id ()
+Resources::Resource::Resource (const string& id_):
+    id (changed, id_)
 {
-    return id;
-};
-
-void Resources::Resource::set_id (const string& new_id)
-{
-    if (ResourceManager::rename_resource (id, new_id))
-	id = new_id;
-
-    changed ();
-};
+}
 
 ostream& Resources::operator<< (ostream &ostr, const Resources::Resource* res)
 {
