@@ -1,4 +1,4 @@
-//$Id: string-res.h,v 1.4 2001/08/18 14:23:01 cactus Exp $ -*- c++ -*-
+//$Id: string-res.h,v 1.6 2001/09/16 13:06:06 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -16,8 +16,8 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
 
-#ifndef GUIKATCHU_STRING_RES_H
-#define GUIKATCHU_STRING_RES_H
+#ifndef GUIKACHU_STRING_RES_H
+#define GUIKACHU_STRING_RES_H
 
 namespace Guikachu
 {
@@ -47,11 +47,11 @@ namespace Guikachu
 	    Property<string> text;
 
 	private:
-	    virtual bool load (xmlDocPtr xml_doc, xmlNodePtr node);
-	    virtual void save (xmlNodePtr node) const;
+	    virtual bool load (StorageNode &node);
+	    virtual void save (StorageNode &node) const;
 	    virtual void save_rcp (ostream &ostr) const;
 	};
     };
 };
 
-#endif /* !GUIKATCHU_STRING_RES_H */
+#endif /* !GUIKACHU_STRING_RES_H */
