@@ -1,4 +1,4 @@
-//$Id: string-win.cc,v 1.7 2001/08/10 16:10:34 cactus Exp $ -*- c++ -*-
+//$Id: string-win.cc,v 1.10 2001/08/31 16:11:37 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -25,46 +25,45 @@
 #include <libgnomeui/gnome-window-icon.h>
 #endif
 
-#include <sigc++/retbind.h>
-#include "argumentsink.h"
+#include "widgets/propertytable.h"
+#include "widgets/entry.h"
+#include "widgets/text.h"
 
 using namespace Guikachu;
 
 GUI::StringWindow::StringWindow (Guikachu::Resources::String *res_):
-    res (res_)
+    res (res_),
+    window (new Gtk::Window (GTK_WINDOW_DIALOG))
 {
-    gui = glade_xml_new (GLADEDIR "/guikachu.glade", NULL);
-
-    using namespace Gtk;
     using namespace SigC;
-    
-    window = wrap (GTK_WINDOW (glade_xml_get_widget (gui, "res_string")));
+
     window->delete_event.connect (slot (this, &StringWindow::delete_event_impl));
+    window->set_policy (false, true, false);
     
 #ifdef USE_WM_ICONS
     gnome_window_icon_set_from_file (window->gtkobj (), GNOME_ICONDIR "/guikachu.png");
 #endif    
 
-    id_entry = wrap (GTK_ENTRY (glade_xml_get_widget (gui, "str_name")));
-    text_entry = wrap (GTK_TEXT (glade_xml_get_widget (gui, "str_text")));
-    
-    id_entry->activate.connect (slot (this, &StringWindow::id_entry_cb));
-    id_entry->focus_out_event.connect (
-	hide<int, GdkEventFocus*> (retbind (slot (this, &StringWindow::id_entry_cb),0)));
-    
-    text_entry->changed.connect (slot (this, &StringWindow::text_entry_cb));
-    text_entry->set_word_wrap (true);
-    
-    block_text_entry_cb = false;
+    GUI::PropertyTable *proptable = new GUI::PropertyTable ();
+    Gtk::Widget *control;
 
+    /* Resource ID */
+    control = new GUI::Entry (false, res->id);
+    proptable->add (_("Resource _ID:"), *manage (control));
+
+    /* String contents */
+    control = new GUI::TextArea (res->text);
+    proptable->add (_("_String:"), *manage (control));
+    
+    window->add (*manage (proptable));
+    
     res->changed.connect (slot (this, &StringWindow::update));
     update ();
 }
 
 GUI::StringWindow::~StringWindow ()
 {
-    window->destroy ();
-    gtk_object_unref (GTK_OBJECT (gui));
+    delete window;
 }
 
 int GUI::StringWindow::delete_event_impl (GdkEventAny *e)
@@ -81,32 +80,7 @@ void GUI::StringWindow::show ()
 
 void GUI::StringWindow::update ()
 {
-    gchar *title_buf = g_strdup_printf (_("String: %s"), res->get_id ().c_str ());
+    gchar *title_buf = g_strdup_printf (_("String: %s"), res->id ().c_str ());
     window->set_title (title_buf);
     g_free (title_buf);
-
-    id_entry->set_text (res->get_id ());
-
-    block_text_entry_cb = true;
-
-    if (text_entry->get_length())
-	text_entry->delete_text (0, text_entry->get_length ());
-    text_entry->insert (res->get_text ());
-
-    block_text_entry_cb = false;
-}
-
-void GUI::StringWindow::id_entry_cb ()
-{
-    res->set_id (id_entry->get_text ());
-}
-
-void GUI::StringWindow::text_entry_cb ()
-{
-    if (block_text_entry_cb)
-	return;
-
-    int saved_pos = text_entry->get_position ();
-    res->set_text (text_entry->get_chars (0, text_entry->get_length ()));
-    gtk_editable_set_position (GTK_EDITABLE (text_entry->gtkobj ()), saved_pos);
 }
