@@ -1,4 +1,4 @@
-//$Id: entry.cc,v 1.1 2001/04/14 18:01:40 cactus Exp $ -*- c++ -*-
+//$Id: entry.cc,v 1.2 2001/08/18 14:23:02 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -24,11 +24,8 @@
 using namespace Guikachu::GUI;
 
 Entry::Entry (bool live_update,
-	      SigC::Slot0<string> get_slot,
-	      SigC::Slot1<void, const string&> set_slot,
-	      SigC::Signal0<void>& changed_sig):
-    get_val (get_slot),
-    set_val (set_slot),
+	      Property<string> &property_):
+    property (property_),
     update_block (false)
 {
     using namespace SigC;
@@ -42,14 +39,14 @@ Entry::Entry (bool live_update,
 	focus_out_event.connect (SigC::hide <int, GdkEventFocus*> (activate_slot));
     }
 
-    changed_sig.connect (slot (this, &Entry::update));
+    property.changed.connect (slot (this, &Entry::update));
     update ();
 }
 
 void Entry::activate_cb ()
 {
     if (!update_block)
-	set_val (get_text ());
+	property = get_text ();
 }
 
 void Entry::changed_cb ()
@@ -58,7 +55,7 @@ void Entry::changed_cb ()
         return;
 
     int saved_pos = get_position ();
-    set_val (get_text ());
+    property = get_text ();
     set_position (saved_pos);
 }
 
@@ -66,7 +63,7 @@ void Entry::update ()
 {
     update_block = true;
 
-    set_text (get_val ());
+    set_text (property);
     
     update_block = false;
 }
