@@ -1,4 +1,4 @@
-//$Id: entry.h,v 1.1 2001/04/14 18:01:40 cactus Exp $ -*- c++ -*-
+//$Id: entry.h,v 1.2 2001/08/18 14:23:02 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -20,6 +20,7 @@
 #define GUIKACHU_WIDGETS_ENTRY_H
 
 #include <gtk--/entry.h>
+#include "property.h"
 
 namespace Guikachu
 {
@@ -27,14 +28,11 @@ namespace Guikachu
     {
 	class Entry: public Gtk::Entry
 	{
-	    SigC::Slot0<string> get_val;
-	    SigC::Slot1<void, const string&> set_val;
+	    Property<string> &property;
 
 	public:
-	    Entry (bool live_update, 
-		   SigC::Slot0<string> get_slot,
-		   SigC::Slot1<void, const string&> set_slot,
-		   SigC::Signal0<void>& changed);
+	    Entry (bool live_update,
+		   Property<string> &property);
 	private:
 	    bool update_block;	    
 	    void update ();
