@@ -1,4 +1,4 @@
-//$Id: widget-combo.cc,v 1.2 2001/08/18 14:23:02 cactus Exp $ -*- c++ -*-
+//$Id: widget-combo.cc,v 1.5 2001/09/19 21:13:57 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -124,7 +124,13 @@ void GUI::WidgetCombo::edit_cb ()
     Widgets::Widget *widget = form->get_widget (current);
     g_return_if_fail (widget != 0);
     
-    widget->show_editor ();
+    set<Widgets::Widget*> widget_set = form->get_widgets ();
+    for (set<Widgets::Widget*>::iterator i = widget_set.begin ();
+	 i != widget_set.end (); i++)
+	(*i)->selected (false);
+    
+    widget->selected (true);
+    widget->request_edit ();
 }
 
 void GUI::WidgetCombo::entry_cb ()
